@@ -1,12 +1,11 @@
-Plot.CA <- function(AC, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
+Plot.CA <- function(AC, Titles = matrix(NA,1,4), Color = TRUE, LinLab = NULL) {
   # Rotina para Plotar Graficos do Metodo AC desenvolvida 
   # por Paulo Cesar Ossani em 11/2014
   
   # Entrada:
-  # AC     - Dados da funcao CA
-  # Titles - Titulos para os graficos
-  # Color  - "s" para graficos coloridos (default)
-  #          "n" para graficos em preto e branco
+  # AC     - Dados da funcao CA.
+  # Titles - Titulos para os graficos.
+  # Color  - Graficos coloridos (default = TRUE).
   # LinLab - Vetor com o rotulo para as linhas para dados de frequencia,
   #          se nao informado retorna o padrao dos dados.
   
@@ -20,10 +19,8 @@ Plot.CA <- function(AC, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   if (!is.character(Titles[3]) || is.na(Titles[3])) Titles[3] = c("Grafico Correspondente as Colunas(Variaveis)")
   if (!is.character(Titles[4]) || is.na(Titles[4])) Titles[4] = c("Grafico Correspondente as Observacoes e Variaveis")
   
-  Color <- toupper(Color) # transforma em maiusculo
-  
-  if (Color!="S" && Color!="N")
-     stop("Entrada para 'Color' esta incorreta, deve ser do tipo caracter, sendo 's' ou 'n'. Verifique!")
+  if (!is.logical(Color))
+     stop("Entrada para 'Color' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
   
   if (!is.null(LinLab) && length(LinLab)!=nrow(AC$MatrixX) && AC$TypData=="F")
      stop("O numero elementos do rotulo para linhas 'LinLab' difere do numero de linhas da base de dados. Verifique!")
@@ -31,8 +28,8 @@ Plot.CA <- function(AC, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   if (is.null(LinLab) && AC$TypData=="F")
      LinLab <- rownames(AC$MatrixX)
   
-  DescEixo1  = paste("Primeira Coordenada Principal (",round(AC$MatrixAutoVlr[1,2],2),"%)",sep="")
-  DescEixo2  = paste("Segunda Coordenada Principal (",round(AC$MatrixAutoVlr[2,2],2),"%)",sep="")
+  DescEixo1 = paste("Primeira coordenada principal (",round(AC$MatrixAutoVlr[1,2],2),"%)",sep="")
+  DescEixo2 = paste("Segunda coordenada principal (",round(AC$MatrixAutoVlr[2,2],2),"%)",sep="")
   #####   FIM - Informacoes usadas nos Graficos  #####
   
   ##### INICIO - Plotagem dos Autovalores #####
@@ -49,15 +46,15 @@ Plot.CA <- function(AC, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   ##### INICIO - Plotagem dos Dados das linhas #####
   if (AC$TypData=="F") { # plota se nao for analise de correspondencia multipla
     plot(AC$MatrixX, # cria grafico para as coordenadas principais das linhas
-         xlab = DescEixo1,  # Nomeia Eixo X
-         ylab = DescEixo2,  # Nomeia Eixo Y
-         main = Titles[2],  # Titulo
-         asp = 1,           # Aspecto do Grafico
-         pch = 17,          # Formato dos pontos 
-         cex=1,             # Tamanho dos pontos
-         xlim=c(min(AC$MatrixX[,1])-0.1,max(AC$MatrixX[,1])+0.1), # Dimensao para as linhas do grafico
-         ylim=c(min(AC$MatrixX[,2]-0.1),max(AC$MatrixX[,2])+0.1), # Dimensao para as colunas do grafico
-         col = ifelse(Color=="S","red","black"))             # Cor dos pontos
+         xlab = DescEixo1, # Nomeia Eixo X
+         ylab = DescEixo2, # Nomeia Eixo Y
+         main = Titles[2], # Titulo
+         asp  = 1,  # Aspecto do Grafico
+         pch  = 17, # Formato dos pontos 
+         cex  = 1,  # Tamanho dos pontos
+         xlim = c(min(AC$MatrixX[,1])-0.1,max(AC$MatrixX[,1])+0.1), # Dimensao para as linhas do grafico
+         ylim = c(min(AC$MatrixX[,2]-0.1),max(AC$MatrixX[,2])+0.1), # Dimensao para as colunas do grafico
+         col  = ifelse(Color,"red","black")) # Cor dos pontos
     
     abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
     
@@ -68,15 +65,15 @@ Plot.CA <- function(AC, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   
   ##### INICIO - Plotagem Dados das colunas #####
   plot(AC$MatrixY, # cria grafico para as coordenadas principais das linhas
-       xlab = DescEixo1,  # Nomeia Eixo X
-       ylab = DescEixo2,  # Nomeia Eixo Y
-       main = Titles[3],  # Titulo
-       asp = 1,           # Aspecto do Grafico
-       pch = ifelse(AC$TypData=="C",17,16),          # Formato dos pontos 
-       cex=1.2,           # Tamanho dos pontos
-       xlim=c(min(AC$MatrixY[,1])-0.1,max(AC$MatrixY[,1])+0.1), # Dimensao para as linhas do grafico
-       ylim=c(min(AC$MatrixY[,2]-0.1),max(AC$MatrixY[,2])+0.1), # Dimensao para as colunas do grafico
-       col = ifelse(Color=="S",ifelse(AC$TypData=="C","red","blue"),"black"))             # Cor dos pontos
+       xlab = DescEixo1, # Nomeia Eixo X
+       ylab = DescEixo2, # Nomeia Eixo Y
+       main = Titles[3], # Titulo
+       asp  = 1,   # Aspecto do Grafico
+       pch  = ifelse(AC$TypData=="C",17,16), # Formato dos pontos 
+       cex  = 1.2, # Tamanho dos pontos
+       xlim = c(min(AC$MatrixY[,1])-0.1,max(AC$MatrixY[,1])+0.1), # Dimensao para as linhas do grafico
+       ylim = c(min(AC$MatrixY[,2]-0.1),max(AC$MatrixY[,2])+0.1), # Dimensao para as colunas do grafico
+       col  = ifelse(Color,ifelse(AC$TypData=="C","red","blue"),"black"))             # Cor dos pontos
   
   abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
   
@@ -85,19 +82,19 @@ Plot.CA <- function(AC, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   ##### FIM - Plotagem Dados das colunas #####
   
   ##### INICIO - Plotagem dos Dados das linhas e colunas conjuntamente #####
-  if (AC$TypData=="F") {     # plota se nao for analise de correspondencia multipla
-     plot(AC$MatrixX,        # cria grafico para as coordenadas principais das linhas
-          xlab = DescEixo1,  # Nomeia Eixo X
-          ylab = DescEixo2,  # Nomeia Eixo Y
-          main = Titles[4],  # Titulo
-          asp = 1,           # Aspecto do Grafico
-          pch = 17,          # Formato dos pontos 
-          cex=1,             # Tamanho dos pontos
-          xlim=c(min(AC$MatrixX[,1],AC$MatrixY)-0.1,max(AC$MatrixX[,1],AC$MatrixY)+0.1), # Dimensao para as linhas do grafico
-          ylim=c(min(AC$MatrixX[,2],AC$MatrixY)-0.1,max(AC$MatrixX[,2],AC$MatrixY)+0.1), # Dimensao para as colunas do grafico
-          col = ifelse(Color=="S","red","black"))             # Cor dos pontos
+  if (AC$TypData=="F") { # plota se nao for analise de correspondencia multipla
+     plot(AC$MatrixX,    # cria grafico para as coordenadas principais das linhas
+          xlab = DescEixo1, # Nomeia Eixo X
+          ylab = DescEixo2, # Nomeia Eixo Y
+          main = Titles[4], # Titulo
+          asp  = 1,  # Aspecto do Grafico
+          pch  = 17, # Formato dos pontos 
+          cex  = 1,  # Tamanho dos pontos
+          xlim = c(min(AC$MatrixX[,1],AC$MatrixY)-0.1,max(AC$MatrixX[,1],AC$MatrixY)+0.1), # Dimensao para as linhas do grafico
+          ylim = c(min(AC$MatrixX[,2],AC$MatrixY)-0.1,max(AC$MatrixX[,2],AC$MatrixY)+0.1), # Dimensao para as colunas do grafico
+          col  = ifelse(Color,"red","black")) # Cor dos pontos
     
-     points(AC$MatrixY, pch = 16, cex = 1.2, col = ifelse(Color=="S","blue","black")) # adiciona ao grafico as coordenadas principais das colunas
+     points(AC$MatrixY, pch = 16, cex = 1.2, col = ifelse(Color,"blue","black")) # adiciona ao grafico as coordenadas principais das colunas
     
      abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
     
