@@ -1,12 +1,11 @@
-Plot.FA <- function(FA, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
+Plot.FA <- function(FA, Titles = matrix(NA,1,4), Color = TRUE, LinLab = NULL) {
   # Rotina para Plotar Graficos do Metodo FA desenvolvida 
   # por Paulo Cesar Ossani em 02/2017
   
   # Entrada:
   # FA     - Dados da funcao FA
   # Titles - Titulos para os graficos
-  # Color  - "s" para graficos coloridos (default)
-  #          "n" para graficos em preto e branco
+  # Color  - Graficos coloridos (default = TRUE).
   # LinLab - Vetor com o rotulo para as linhas, se nao
   #          informado retorna o padrao dos dados.
   
@@ -20,10 +19,8 @@ Plot.FA <- function(FA, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   if (!is.character(Titles[3]) || is.na(Titles[3])) Titles[3] = c("Cargas fatoriais")
   if (!is.character(Titles[4]) || is.na(Titles[4])) Titles[4] = c("Biplot")
   
-  Color <- toupper(Color) # transforma em maiusculo
-  
-  if (Color!="S" && Color!="N")
-     stop("Entrada para 'Color' esta incorreta, deve ser do tipo caracter, sendo 's' ou 'n'. Verifique!")
+  if (!is.logical(Color))
+     stop("Entrada para 'Color' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
   
   if (!is.null(LinLab) && length(LinLab)!=nrow(FA$MatrixScores))
      stop("O numero elementos do rotulo para linhas 'LinLab' difere do numero de linhas da base de dados. Verifique!")
@@ -31,8 +28,8 @@ Plot.FA <- function(FA, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   if (is.null(LinLab))
      LinLab <- rownames(FA$MatrixScores)
   
-  DescEixo1  = "Primeiro Fator"
-  DescEixo2  = "Segundo Fator"
+  DescEixo1 = "Primeiro fator"
+  DescEixo2 = "Segundo fator"
   #####   FIM - Informacoes usadas nos Graficos  #####
   
   ##### INICIO - Plotagem dos Autovalores #####
@@ -47,18 +44,18 @@ Plot.FA <- function(FA, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   ##### FIM - Scree-plot dos Fatores #####
   
   ##### INICIO - Plotagem Escores das observacoes #####
-  plot(FA$MatrixScores, # cria grafico para os Escores das observacoes 
-       xlab = DescEixo1,  # Nomeia Eixo X
-       ylab = DescEixo2,  # Nomeia Eixo Y
-       main = Titles[2],  # Titulo
-       asp = 1,           # Aspecto do Grafico
-       pch = 15,          # Formato dos pontos
-       cex = 1,           # Tamanho dos pontos
-       xlim=c(min(FA$MatrixScores[,1])-0.05,max(FA$MatrixScores[,1])+0.05), # Dimensao para as linhas do grafico
-       ylim=c(min(FA$MatrixScores[,2])-0.05,max(FA$MatrixScores[,2])+0.05), # Dimensao para as colunas do grafico
-       col = ifelse(Color=="S","red","black"))  # Cor dos pontos
+  plot(FA$MatrixScores,  # cria grafico para os Escores das observacoes 
+       xlab = DescEixo1, # Nomeia Eixo X
+       ylab = DescEixo2, # Nomeia Eixo Y
+       main = Titles[2], # Titulo
+       asp  = 1,  # Aspecto do Grafico
+       pch  = 15, # Formato dos pontos
+       cex  = 1,  # Tamanho dos pontos
+       xlim = c(min(FA$MatrixScores[,1])-0.05,max(FA$MatrixScores[,1])+0.05), # Dimensao para as linhas do grafico
+       ylim = c(min(FA$MatrixScores[,2])-0.05,max(FA$MatrixScores[,2])+0.05), # Dimensao para as colunas do grafico
+       col  = ifelse(Color,"red","black")) # Cor dos pontos
 
-  abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
+  abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
 
   #text(FA$MatrixScores, cex = 1, pos = 3, LinLab)  # Coloca os nomes dos pontos das coordenadas principais das linhas
   LocLab(FA$MatrixScores, cex = 1, LinLab)
@@ -66,63 +63,63 @@ Plot.FA <- function(FA, Titles = matrix(NA,1,4), Color = "s", LinLab = NULL) {
   
   ##### INICIO - Cargas fatoriais #####
   HpMat <- rbind(c(0,0),FA$MatrixCarga[,1:2])
-  MaxX <- max(HpMat[,1])+0.05 # Dimenssoes maximas das linhas
-  MinX <- min(HpMat[,1])-0.05 # Dimenssoes minimas das linhas
-  MaxY <- max(HpMat[,2])+0.05 # Dimenssoes maximas das colunas
-  MinY <- min(HpMat[,2])-0.05 # Dimenssoes minimas das colunas
+  MaxX  <- max(HpMat[,1]) + 0.05 # Dimenssoes maximas das linhas
+  MinX  <- min(HpMat[,1]) - 0.05 # Dimenssoes minimas das linhas
+  MaxY  <- max(HpMat[,2]) + 0.05 # Dimenssoes maximas das colunas
+  MinY  <- min(HpMat[,2]) - 0.05 # Dimenssoes minimas das colunas
   
   plot(0,0, # Plota as variaveis
        xlab = DescEixo1, # Nomeia Eixo X
        ylab = DescEixo2, # Nomeia Eixo Y
        main = Titles[3], # Titulo
-       asp = 1,           # Aspecto do grafico
-       cex=0,             # Tamanho dos pontos
-       xlim=c(MinX,MaxX), # Dimensao para as linhas do grafico
-       ylim=c(MinY,MaxY)) # Dimensao para as colunas do grafico
+       asp  = 1, # Aspecto do grafico
+       cex  = 0, # Tamanho dos pontos
+       xlim = c(MinX,MaxX), # Dimensao para as linhas do grafico
+       ylim = c(MinY,MaxY)) # Dimensao para as colunas do grafico
        # xlim=c(min(FA$MatrixCarga[,1])-0.05,max(FA$MatrixCarga[,1])+0.05), # Dimensao para as linhas do grafico
        # ylim=c(min(FA$MatrixCarga[,2])-0.05,max(FA$MatrixCarga[,2])+0.05)) # Dimensao para as colunas do grafico
        
   abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
   
-  arrows(0,0,FA$MatrixCarga[,1],FA$MatrixCarga[,2], lwd = 1, code = 2, length = 0.08, angle = 25, col = ifelse(Color=="S","Red","Black")) # cria a seta apontando para cada variavel  
+  arrows(0,0,FA$MatrixCarga[,1],FA$MatrixCarga[,2], lwd = 1, code = 2, length = 0.08, angle = 25, col = ifelse(Color,"Red","Black")) # cria a seta apontando para cada variavel  
   
   NomeVar <- rownames(FA$MatrixCarga) # nomes das variaveis
-  LocLab(FA$MatrixCarga[,1:2], NomeVar, col = ifelse(Color=="S","Blue","Black"))  # Coloca os nomes das variaveis
+  LocLab(FA$MatrixCarga[,1:2], NomeVar, col = ifelse(Color,"Blue","Black"))  # Coloca os nomes das variaveis
   ##### FIM - Cargas fatoriais #####
 
   
   ##### INICIO - Biplot ##### 
   HpMat <- rbind(c(0,0),FA$MatrixCarga[,1:2],FA$MatrixScores[,1:2])
-  MaxX <- max(HpMat[,1])+0.05 # Dimenssoes maximas das linhas
-  MinX <- min(HpMat[,1])-0.05 # Dimenssoes minimas das linhas
-  MaxY <- max(HpMat[,2])+0.05 # Dimenssoes maximas das colunas
-  MinY <- min(HpMat[,2])-0.05 # Dimenssoes minimas das colunas
+  MaxX  <- max(HpMat[,1]) + 0.05 # Dimenssoes maximas das linhas
+  MinX  <- min(HpMat[,1]) - 0.05 # Dimenssoes minimas das linhas
+  MaxY  <- max(HpMat[,2]) + 0.05 # Dimenssoes maximas das colunas
+  MinY  <- min(HpMat[,2]) - 0.05 # Dimenssoes minimas das colunas
   # MaxX <- max(FA$MatrixCarga[,1],FA$MatrixScores[,1])+0.05 # Dimenssoes maximas das linhas
   # MinX <- min(FA$MatrixCarga[,1],FA$MatrixScores[,1])-0.05 # Dimenssoes minimas das linhas
   # MaxY <- max(FA$MatrixCarga[,2],FA$MatrixScores[,2])+0.05 # Dimenssoes maximas das colunas
   # MinY <- min(FA$MatrixCarga[,2],FA$MatrixScores[,2])-0.05 # Dimenssoes minimas das colunas
   
   plot(0,0, # Plota as variaveis
-       xlab = DescEixo1,  # Nomeia Eixo X
-       ylab = DescEixo2,  # Nomeia Eixo Y
-       main = Titles[4],  # Titulo
-       asp = 1,           # Aspecto do grafico
-       cex=0,             # Tamanho dos pontos
-       xlim=c(MinX,MaxX), # Dimensao para as linhas do grafico
-       ylim=c(MinY,MaxY)) # Dimensao para as colunas do grafico
+       xlab = DescEixo1, # Nomeia Eixo X
+       ylab = DescEixo2, # Nomeia Eixo Y
+       main = Titles[4], # Titulo
+       asp  = 1, # Aspecto do grafico
+       cex  = 0, # Tamanho dos pontos
+       xlim = c(MinX,MaxX), # Dimensao para as linhas do grafico
+       ylim = c(MinY,MaxY)) # Dimensao para as colunas do grafico
 
   abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
   
-  arrows(0,0,FA$MatrixCarga[,1],FA$MatrixCarga[,2], lwd = 1, code = 2, length = 0.08, angle = 25, col = ifelse(Color=="S","Black","Black")) # cria a seta apontando para cada variavel  
+  arrows(0,0,FA$MatrixCarga[,1],FA$MatrixCarga[,2], lwd = 1, code = 2, length = 0.08, angle = 25, col = ifelse(Color,"Black","Black")) # cria a seta apontando para cada variavel  
   
   NomeVar <- rownames(FA$MatrixCarga) # nomes das variaveis
-  LocLab(FA$MatrixCarga[,1:2], NomeVar, col = ifelse(Color=="S","Blue","Black"))  # Coloca os nomes das variaveis
+  LocLab(FA$MatrixCarga[,1:2], NomeVar, col = ifelse(Color,"Blue","Black"))  # Coloca os nomes das variaveis
   
   points(FA$MatrixScores,    # Coloca pontos nas posicoes dos individuos
-         asp = 1,   # Aspecto do grafico
-         pch = 15,  # Formato dos pontos 
-         cex = 1,   # Tamanho dos pontos         
-         col = ifelse(Color=="S","Red","Black"))
+         asp = 1,  # Aspecto do grafico
+         pch = 15, # Formato dos pontos 
+         cex = 1,  # Tamanho dos pontos         
+         col = ifelse(Color,"Red","Black"))
   
   LocLab(FA$MatrixScores, cex = 1, LinLab)
   ##### FIM - Biplot #####
